summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolderimap.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfolderimap.h')
-rw-r--r--kmail/kmfolderimap.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kmail/kmfolderimap.h b/kmail/kmfolderimap.h
index 059e1a4c..490b13a6 100644
--- a/kmail/kmfolderimap.h
+++ b/kmail/kmfolderimap.h
@@ -372,9 +372,9 @@ public slots:
virtual void take(TQPtrList<KMMessage>);
/**
* Add the data a KIO::Job retrieves to the buffer
*/
- void slotSimpleData(KIO::Job * job, const TQByteArray & data);
+ void slotSimpleData(TDEIO::Job * job, const TQByteArray & data);
/**
* Convert IMAP flags to a message status
@@ -426,7 +426,7 @@ protected:
virtual FolderJob* doCreateJob( TQPtrList<KMMessage>& msgList, const TQString& sets,
FolderJob::JobType jt, KMFolder *folder ) const;
- void getMessagesResult(KIO::Job * job, bool lastSet);
+ void getMessagesResult(TDEIO::Job * job, bool lastSet);
/** Called by KMFolder::expunge() to delete the actual contents.
At the time of the call the folder has already been closed, and
@@ -452,7 +452,7 @@ protected slots:
* Retrieve the whole folder or only the changes
*/
void checkValidity();
- void slotCheckValidityResult(KIO::Job * job);
+ void slotCheckValidityResult(TDEIO::Job * job);
/**
* Get the folder now (internal)
@@ -462,30 +462,30 @@ protected slots:
/**
* For listing the contents of a folder
*/
- void slotListFolderResult(KIO::Job * job);
- void slotListFolderEntries(KIO::Job * job, const KIO::UDSEntryList & uds);
+ void slotListFolderResult(TDEIO::Job * job);
+ void slotListFolderEntries(TDEIO::Job * job, const TDEIO::UDSEntryList & uds);
/**
* For retrieving a message digest
*/
- void slotGetMessagesResult(KIO::Job * job);
- void slotGetLastMessagesResult(KIO::Job * job);
- void slotGetMessagesData(KIO::Job * job, const TQByteArray & data);
+ void slotGetMessagesResult(TDEIO::Job * job);
+ void slotGetLastMessagesResult(TDEIO::Job * job);
+ void slotGetMessagesData(TDEIO::Job * job, const TQByteArray & data);
/**
* For creating a new subfolder
*/
- void slotCreateFolderResult(KIO::Job * job);
+ void slotCreateFolderResult(TDEIO::Job * job);
/**
* Remove the folder also locally, if removing on the server succeeded
*/
- void slotRemoveFolderResult(KIO::Job *job);
+ void slotRemoveFolderResult(TDEIO::Job *job);
/**
* Update the number of unseen messages
*/
- void slotStatResult(KIO::Job *job);
+ void slotStatResult(TDEIO::Job *job);
/**
* notify the progress item that the mail check for this folder is
@@ -372,9 +372,9 @@ public slots:
virtual void take(TQPtrList<KMMessage>);
/**
- * Add the data a KIO::Job retrieves to the buffer
+ * Add the data a TDEIO::Job retrieves to the buffer
*/